==> cabal-helper-0.7.3.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/cabal-helper.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.7.3.0
id: cabal-helper-0.7.3.0-32twHOTdCSYLJpcokbkspO
key: cabal-helper-0.7.3.0-32twHOTdCSYLJpcokbkspO
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state used by ghc-mod
description:
    @cabal-helper@ provides a library which wraps the internal use of an
    executable to lift the restrictions imposed by linking against versions of
    GHC before @7.10@. This has the pleasant side effect of isolating the user
    from having to deal with Cabal version changes manually as @cabal-helper@
    can simply recompile it'\''s helper program automatically as needed.
    .
    @cabal-helper@ uses a wrapper executable to compile the actual cabal-helper
    executable at runtime while linking against an arbitrary version of
    Cabal. This runtime-compiled helper executable is then used to extract
    various bits and peices from Cabal\'\''s on disk state (dist/setup-config)
    written by it'\''s configure command.
    .
    In addition to this the wrapper executable also supports installing any
    version of Cabal from hackage in case it cannot be found in any available
    package database. The wrapper installs these instances of the Cabal library
    into a private package database so as to not interfere with the user'\''s
    packages.
    .
    Furthermore the wrapper supports one special case namely reading a state
    file for Cabal itself. This is needed as Cabal compiles it'\''s Setup.hs using
    itself and not using any version of Cabal installed in any package database.
    .
    @cabal-helper@ can compile with @Cabal >= 1.14@ but requires @Cabal >= 1.16@
    at runtime.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Helper
hidden-modules: Paths_cabal_helper CabalHelper.Types
                CabalHelper.Sandbox
abi: 22890e7200a97ef4f3122968b05a8e02
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cabal-helper-0.7.3.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/cabal-helper-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/cabal-helper-0.7.3.0
hs-libraries: HScabal-helper-0.7.3.0-32twHOTdCSYLJpcokbkspO
depends:
    base-4.10.0.0 Cabal-2.0.0.2 directory-1.3.0.2 filepath-1.4.1.2
    transformers-0.5.2.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    process-1.6.1.0 ghc-prim-0.5.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             Cabal-2.0.0.2=c8eb33a4731ce0ca1f6ddb3df7f6d80c
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             filepath-1.4.1.2=30ad74f2069d36b2d0af3972630d4ac4
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=5531911f09693672654e6de645ce55e7
             process-1.6.1.0=b3854816fc29ad3caa05e87ab6680404
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cabal-helper-0.7.3.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/cabal-helper.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.7.3.0
id: cabal-helper-0.7.3.0-8AlXW6i6L2JHpWLmuzkhA3
key: cabal-helper-0.7.3.0-8AlXW6i6L2JHpWLmuzkhA3
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state used by ghc-mod
description:
    @cabal-helper@ provides a library which wraps the internal use of an
    executable to lift the restrictions imposed by linking against versions of
    GHC before @7.10@. This has the pleasant side effect of isolating the user
    from having to deal with Cabal version changes manually as @cabal-helper@
    can simply recompile it'\''s helper program automatically as needed.
    .
    @cabal-helper@ uses a wrapper executable to compile the actual cabal-helper
    executable at runtime while linking against an arbitrary version of
    Cabal. This runtime-compiled helper executable is then used to extract
    various bits and peices from Cabal\'\''s on disk state (dist/setup-config)
    written by it'\''s configure command.
    .
    In addition to this the wrapper executable also supports installing any
    version of Cabal from hackage in case it cannot be found in any available
    package database. The wrapper installs these instances of the Cabal library
    into a private package database so as to not interfere with the user'\''s
    packages.
    .
    Furthermore the wrapper supports one special case namely reading a state
    file for Cabal itself. This is needed as Cabal compiles it'\''s Setup.hs using
    itself and not using any version of Cabal installed in any package database.
    .
    @cabal-helper@ can compile with @Cabal >= 1.14@ but requires @Cabal >= 1.16@
    at runtime.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Helper
hidden-modules: Paths_cabal_helper CabalHelper.Types
                CabalHelper.Sandbox
abi: 7a63a1d005e24393ad4f2cbc5bf7b130
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.7.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cabal-helper-0.7.3.0
hs-libraries: HScabal-helper-0.7.3.0-8AlXW6i6L2JHpWLmuzkhA3
depends:
    base-4.10.1.0 Cabal-2.0.1.0 directory-1.3.0.2 filepath-1.4.1.2
    transformers-0.5.2.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    process-1.6.1.0 ghc-prim-0.5.1.1 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
